@@ -321,6 +321,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq devdocs-browser-cache-directory  (var "devdocs/browser-cache/"))
     (setq devdocs-data-dir                 (var "devdocs/data/"))
     (setq dired-recent-directories-file    (var "dired-recent-directories.el"))
+    (setq dirvish-cache-dir                (var "dirvish/cache"))
     (setq elbank-data-file                 (var "elbank-data.el"))
     (setq elmo-msgdb-directory             (var "elmo/"))
     (setq elmo-split-log-file              (var "elmo/split-log"))
@@ -377,6 +378,7 @@ directories."
     (eval-after-load 'lookup
       `(make-directory ,(etc "lookup/") t))
     (setq lookup-init-directory            (etc "lookup/"))
+    (setq lsp-clojure-workspace-dir        (var "lsp-clojure/workspace/"))
     (setq lsp-eslint-library-choices-file  (var "lsp/eslint-library-choices.el"))
     (setq lsp-python-ms-dir                (var "lsp-python-ms/"))
     (eval-after-load 'lsp-mode
